Sub page 1 with a very long page title so that it is sure to wrap
=================================================================

This is sub page 1.

This is an extremely long caption for the first set of TOC entries, we are making it long so that it wraps.
-----------------------------------------------------------------------------------------------------------

.. toctree::
   :caption: This is an extremely long caption for the first set of TOC entries, we are making it long so that it wraps.

   subpage1subpage1

.. toctree::
   :caption: This is another extremely long caption for the second set of TOC entries.

   subpage1subpage2
